@@ -64,8 +64,7 @@ extensions = [
     'sphinx_automodapi.automodapi',
     'sphinx_automodapi.smart_resolver',
     'sphinx_copybutton',
-    'sphinx_inline_tabs',
-    'sphinx_panels',
+    'sphinx_design',
     'sphinxcontrib.apidoc',
     'myst_parser',
     'nbsphinx',
@@ -85,7 +84,7 @@ nbsphinx_allow_errors = True
 # Prefixes to shorten common links
 extlinks = {
     'issue': ('https://github.com/pyinat/pyinaturalist/issues/%s', 'issue #%s'),
-    'v0': ('https://www.inaturalist.org/pages/api+reference#', '%s'),
+    'v0': ('https://www.inaturalist.org/pages/api+reference#%s', '%s'),
     'v1': ('https://api.inaturalist.org/v1/docs/#/%s', '%s'),
     'v2': ('https://api.inaturalist.org/v2/docs/#/%s', '%s'),
 }
@@ -158,8 +157,7 @@ html_css_files = [
     'collapsible_container.css',
     'colors.css',
     'table.css',
-    'https://use.fontawesome.com/releases/v5.15.3/css/all.css',
-    'https://use.fontawesome.com/releases/v5.15.3/css/v4-shims.css',
+    'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css',
 ]
 html_show_sphinx = False
 pygments_style = 'friendly'
