@@ -1,7 +1,8 @@
 """Controller classes for :py:class:`.iNatClient`"""
 # flake8: noqa: F401
 from pyinaturalist.controllers.base_controller import BaseController
-from pyinaturalist.controllers.observations_controller import ObservationController
+from pyinaturalist.controllers.controlled_term_controller import ControlledTermController
+from pyinaturalist.controllers.observation_controller import ObservationController
 from pyinaturalist.controllers.place_controller import PlaceController
 from pyinaturalist.controllers.project_controller import ProjectController
 from pyinaturalist.controllers.taxon_controller import TaxonController
