@@ -193,7 +193,7 @@ def strip_empty_values(values: Dict) -> Dict:
 # -------------------
 
 
-def ensure_file_obj(value: AnyFile, session: Session = None) -> IO:
+def ensure_file_obj(value: AnyFile, session: Optional[Session] = None) -> IO:
     """Load data into a file-like object, if it isn't already. Accepts local file paths and URLs."""
     # Load from URL
     if isinstance(value, str) and URL_PATTERN.match(value):
@@ -276,7 +276,7 @@ def format_license(value: str) -> Optional[str]:
 
 
 def try_datetime(timestamp: Any, **kwargs) -> Optional[datetime]:
-    """Parse a timestamp string into a datetime, if valid; return ``None`` otherwise"""
+    """Parse a date/time string into a datetime, if valid; return ``None`` otherwise"""
     if isinstance(timestamp, datetime):
         return timestamp
     if not timestamp or not str(timestamp).strip():
@@ -292,6 +292,12 @@ def try_datetime(timestamp: Any, **kwargs) -> Optional[datetime]:
         return None
 
 
+def try_date(timestamp: Any, **kwargs) -> Optional[date]:
+    """Parse a date string into a date, if valid; return ``None`` otherwise"""
+    dt = try_datetime(timestamp, **kwargs)
+    return dt.date() if dt else None
+
+
 def try_float(value: Any) -> Optional[float]:
     """Convert a value to a float, if valid; return ``None`` otherwise"""
     try:
