@@ -20,10 +20,15 @@ from pyinaturalist.models.lazy_property import LazyProperty, add_lazy_attrs, get
 
 # Attrs class decorators with the most commonly used options
 define_model: Callable = define(auto_attribs=False, field_transformer=add_lazy_attrs)
+define_model_custom_init: Callable = define(
+    auto_attribs=False, init=False, field_transformer=add_lazy_attrs
+)
 define_model_collection: Callable = define(auto_attribs=False, order=False, slots=False)
 
 
-def field(doc: str = '', options: Iterable = None, metadata: Dict = None, **kwargs):
+def field(
+    doc: str = '', options: Optional[Iterable] = None, metadata: Optional[Dict] = None, **kwargs
+):
     """A field with extra metadata for documentation and options"""
     metadata = metadata or {}
     metadata['doc'] = doc
@@ -37,7 +42,7 @@ def is_in(options: Iterable):
     return validators.in_(list(options) + [None])
 
 
-def coordinate_pair(doc: str = None, **kwargs):
+def coordinate_pair(doc: Optional[str] = None, **kwargs):
     """Field containing a pair of coordiantes"""
     return field(
         default=None,
@@ -68,12 +73,8 @@ def upper(value) -> Optional[str]:
 from pyinaturalist.models.photo import IconPhoto, Photo
 from pyinaturalist.models.place import Place
 from pyinaturalist.models.user import User, UserCount, UserCounts
-from pyinaturalist.models.taxon_meta import (
-    ConservationStatus,
-    EstablishmentMeans,
-    ListedTaxon,
-    TaxonSummary,
-)
+from pyinaturalist.models.checklist import Checklist, EstablishmentMeans, ListedTaxon
+from pyinaturalist.models.conservation_status import ConservationStatus, TaxonSummary
 from pyinaturalist.models.taxon import Taxon, TaxonCount, TaxonCounts
 from pyinaturalist.models.controlled_term import (
     Annotation,
@@ -82,8 +83,7 @@ from pyinaturalist.models.controlled_term import (
     ControlledTermCounts,
     ControlledTermValue,
 )
-from pyinaturalist.models.comment import Comment
-from pyinaturalist.models.identification import Identification
+from pyinaturalist.models.identification import Comment, Identification
 from pyinaturalist.models.life_list import LifeList, LifeListTaxon
 from pyinaturalist.models.message import Message
 from pyinaturalist.models.observation_field import ObservationField, ObservationFieldValue
