@@ -1,7 +1,5 @@
 from datetime import datetime
-from typing import Any, Dict, List, Optional
-
-from attr import define
+from typing import Any, Dict, List
 
 from pyinaturalist.constants import (
     ALL_LICENSES,
@@ -18,6 +16,7 @@ from pyinaturalist.models import (
     BaseModel,
     BaseModelCollection,
     Comment,
+    IconPhoto,
     Identification,
     LazyProperty,
     ObservationFieldValue,
@@ -25,17 +24,17 @@ from pyinaturalist.models import (
     ProjectObservation,
     Taxon,
     User,
-    add_lazy_attrs,
     coordinate_pair,
     datetime_field,
     datetime_now_field,
     define_model_collection,
+    define_model_custom_init,
     field,
     upper,
 )
 
 
-@define(auto_attribs=False, init=False, field_transformer=add_lazy_attrs)
+@define_model_custom_init
 class Observation(BaseModel):
     """:fa:`binoculars` An observation, based the schema of
     :v1:`GET /observations <Observations/get_observations>`
@@ -51,7 +50,7 @@ class Observation(BaseModel):
         factory=list, doc='Details on users who have favorited the observation'
     )
     geoprivacy: str = field(default=None, options=GEOPRIVACY_LEVELS, doc='Location privacy level')
-    identifications_count: int = field(default=None, doc='Total number of identifications')
+    identifications_count: int = field(default=0, doc='Total number of identifications')
     identifications_most_agree: bool = field(
         default=None, doc='Indicates if most identifications agree with the community ID'
     )
@@ -187,13 +186,17 @@ class Observation(BaseModel):
     # Attributes that will only be used during init and then omitted
     temp_attrs = ['time_observed_at']
 
-    # Convert observation timestamps prior to __attrs_init__
     def __init__(self, **kwargs):
+        # Convert observation timestamps prior to __attrs_init__
         observed_on = kwargs.pop('time_observed_at', None)
         if not isinstance(kwargs['observed_on'], datetime) and observed_on:
             kwargs['observed_on'] = observed_on
+        # Set default URL based on observation ID
         if not kwargs.get('uri'):
             kwargs['uri'] = f'{INAT_BASE_URL}/observations/{kwargs.get("id", "")}'
+        # Set identifications_count if missing
+        if kwargs.get('identifications') and not kwargs.get('identifications_count'):
+            kwargs['identifications_count'] = len(kwargs['identifications'])
         self.__attrs_init__(**kwargs)  # type: ignore
 
     @classmethod
@@ -205,25 +208,21 @@ class Observation(BaseModel):
         return cls.from_json(json)
 
     @property
-    def photo_url(self) -> Optional[str]:
-        """Original size photo URL for first observation photo (if any)"""
-        if not self.photos:
-            return None
-        return self.photos[0].original_url
-
-    @property
-    def thumbnail_url(self) -> Optional[str]:
-        """Thumbnail size photo URL for first observation photo (if any)"""
-        if not self.photos:
-            return None
-        return self.photos[0].thumbnail_url
+    def default_photo(self) -> Photo:
+        """Get the default observation photo if any; otherwise use taxon default photo or icon"""
+        if self.photos:
+            return self.photos[0]
+        elif self.taxon:
+            return self.taxon.icon
+        else:
+            return IconPhoto.from_iconic_taxon('unknown')
 
     @property
     def _row(self) -> TableRow:
         return {
             'ID': self.id,
-            'Taxon ID': self.taxon.id,
-            'Taxon': self.taxon.full_name,
+            'Taxon ID': self.taxon.id if self.taxon else None,
+            'Taxon': self.taxon.full_name if self.taxon else None,
             'Observed on': self.observed_on,
             'User': self.user.login,
             'Location': self.place_guess or self.location,
@@ -252,17 +251,17 @@ class Observations(BaseModelCollection):
         unique_users = {obs.user.id: obs.user for obs in self.data}
         return list(unique_users.values())
 
+    @property
+    def photos(self) -> List[Photo]:
+        """Get default photo for each observation"""
+        return [obs.default_photo for obs in self.data]
+
     @property
     def taxa(self) -> List[Taxon]:
         """Get all unique taxa"""
         unique_taxa = {obs.taxon.id: obs.taxon for obs in self.data}
         return list(unique_taxa.values())
 
-    @property
-    def thumbnail_urls(self) -> List[str]:
-        """Get thumbnails for all observation default photos"""
-        return [obs.thumbnail_url for obs in self.data if obs.thumbnail_url]
-
 
 # Fix __init__ and class docstring
 Observation = extend_init_signature(Observation.__attrs_init__)(Observation)  # type: ignore
