@@ -1,4 +1,4 @@
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 from pyinaturalist.constants import (
     INAT_BASE_URL,
@@ -20,7 +20,7 @@ def convert_optional_lat_long(obj: Union[Dict, List, None, str]):
 
 @define_model
 class Place(BaseModel):
-    """:fa:`map-marker-alt,style=fas` A curated or community-contributed place. Handles data from the following endpoints:
+    """:fa:`location-dot` A curated or community-contributed place. Handles data from the following endpoints:
 
     * `GET /places/{id} <https://api.inaturalist.org/v1/docs/#!/Places/get_places_id>`_
     * `GET /places/nearby <https://api.inaturalist.org/v1/docs/#!/Places/get_places_nearby>`_
@@ -53,7 +53,7 @@ class Place(BaseModel):
     slug: str = field(default=None, doc='Place URL slug')
 
     @classmethod
-    def from_json(cls, value: JsonResponse, category: str = None, **kwargs) -> 'Place':
+    def from_json(cls, value: JsonResponse, category: Optional[str] = None, **kwargs) -> 'Place':
         value.setdefault('category', category)
         return super(Place, cls).from_json(value)
 
