@@ -1,4 +1,6 @@
-from typing import Dict, List
+from string import capwords
+from typing import Dict, List, Optional
+from warnings import warn
 
 from attr import fields_dict
 
@@ -18,6 +20,7 @@ from pyinaturalist.models import (
     BaseModelCollection,
     ConservationStatus,
     EstablishmentMeans,
+    IconPhoto,
     LazyProperty,
     ListedTaxon,
     Photo,
@@ -26,12 +29,11 @@ from pyinaturalist.models import (
     define_model_collection,
     field,
 )
-from pyinaturalist.models.photo import IconPhoto
 
 
 @define_model
 class Taxon(BaseModel):
-    """:fa:`dove,style=fas` An iNaturalist taxon, based on the schema of
+    """:fa:`dove` An iNaturalist taxon, based on the schema of
     `GET /taxa <https://api.inaturalist.org/v1/docs/#!/Taxa/get_taxa>`_.
 
     Can be constructed from either a full or partial JSON record. Examples of partial records
@@ -92,6 +94,7 @@ class Taxon(BaseModel):
         default=None,
         doc='Number indicating rank level, for easier comparison between ranks (kingdom=higest)',
     )
+    reference_url: str = field(default=None, doc='Reference URL for the taxonomy source')
     ranges: bool = field(default=None, doc='Indicates if there is range data for this taxon')
     rank: str = field(default=None, options=RANKS, doc='Taxon rank')
     taxon_changes_count: int = field(default=None, doc='Number of curator changes to this taxon')
@@ -187,7 +190,9 @@ class Taxon(BaseModel):
         elif not self.rank:
             return self.name
 
-        common_name = f' ({self.preferred_common_name})' if self.preferred_common_name else ''
+        common_name = (
+            f' ({capwords(self.preferred_common_name)})' if self.preferred_common_name else ''
+        )
         return f'{self.rank.title()}: {self.name}{common_name}'
 
     @property
@@ -219,20 +224,27 @@ class Taxon(BaseModel):
         """Info URL on iNaturalist.org"""
         return f'{INAT_BASE_URL}/taxa/{self.id}'
 
-    # TODO: Probably remove this
+    # TODO: Experimental; not sure if I want to have API calls in model classes
     @classmethod
     def from_id(cls, id: int) -> 'Taxon':
         """Lookup and create a new Taxon object by ID"""
         from pyinaturalist.v1 import get_taxa_by_id
 
+        warn(DeprecationWarning('This method is deprecated; please use iNatClient.taxa() instead'))
         r = get_taxa_by_id(id)
         return cls.from_json(r['results'][0])
 
     def load_full_record(self):
         """Update this Taxon with full taxon info, including ancestors + children"""
+        msg = 'This method is deprecated; please use iNatClient.taxa.full_record() instead'
+        warn(DeprecationWarning(msg))
+
         t = Taxon.from_id(self.id)
-        for key in fields_dict(Taxon).keys():
-            key = key.lstrip('_')  # Use getters/setters for LazyProperty instead of temp attrs
+        copy_keys = set(fields_dict(Taxon).keys()) - {'matched_term'}
+        for key in copy_keys:
+            # Use getters/setters for LazyProperty instead of temp attrs (cls.foo vs cls._foo)
+            if hasattr(key, key.lstrip('_')):
+                key = key.lstrip('_')
             setattr(self, key, getattr(t, key))
 
     @property
@@ -251,14 +263,16 @@ class Taxon(BaseModel):
 
 @define_model
 class TaxonCount(Taxon):
-    """:fa:`dove,style=fas` :fa:`list` A :py:class:`.Taxon` with an associated count, used in a
+    """:fa:`dove` :fa:`list` A :py:class:`.Taxon` with an associated count, used in a
     :py:class:`.TaxonCounts` collection
     """
 
     count: int = field(default=0, doc='Number of observations of this taxon')
 
     @classmethod
-    def from_json(cls, value: JsonResponse, user_id: int = None, **kwargs) -> 'TaxonCount':
+    def from_json(
+        cls, value: JsonResponse, user_id: Optional[int] = None, **kwargs
+    ) -> 'TaxonCount':
         """Flatten out count + taxon fields into a single-level dict before initializing"""
         if 'results' in value:
             value = value['results']
@@ -284,7 +298,7 @@ class TaxonCount(Taxon):
 
 @define_model_collection
 class TaxonCounts(BaseModelCollection):
-    """:fa:`dove,style=fas` :fa:`list` A collection of taxa with an associated counts. Used with
+    """:fa:`dove` :fa:`list` A collection of taxa with an associated counts. Used with
     :v1:`GET /observations/species_counts <Observations/get_observations_species_counts>`.
     as well as :py:class:`.LifeList`.
     """
