@@ -5,7 +5,7 @@ See: http://api.inaturalist.org/v1/docs/
 Most recent API version tested: 1.3.0
 """
 # flake8: noqa: F401, F403
-from pyinaturalist.v1.controlled_terms import get_controlled_terms
+from pyinaturalist.v1.controlled_terms import get_controlled_terms, get_controlled_terms_for_taxon
 from pyinaturalist.v1.identifications import get_identifications, get_identifications_by_id
 from pyinaturalist.v1.messages import get_message_by_id, get_messages, get_unread_meassage_count
 from pyinaturalist.v1.observation_fields import delete_observation_field, set_observation_field
@@ -21,6 +21,7 @@ from pyinaturalist.v1.observations import (
     get_observation_taxon_summary,
     get_observation_taxonomy,
     get_observations,
+    get_observations_by_id,
     update_observation,
     upload,
 )
