@@ -1,5 +1,7 @@
+# TODO: pprint examples are out of date
 from copy import deepcopy
 from logging import getLogger
+from typing import Optional
 
 from pyinaturalist.constants import (
     API_V1,
@@ -9,7 +11,9 @@ from pyinaturalist.constants import (
     JsonResponse,
     ListResponse,
     MultiFile,
+    MultiInt,
     MultiIntOrStr,
+    ResponseResult,
 )
 from pyinaturalist.converters import (
     convert_all_coordinates,
@@ -30,38 +34,93 @@ from pyinaturalist.session import delete, get, post, put
 logger = getLogger(__name__)
 
 
-@document_common_args
-def get_observation(observation_id: int, **params) -> JsonResponse:
-    """Get details about a single observation by ID
+@document_request_params(
+    *docs._get_observations, docs._pagination, docs._only_id, docs._access_token
+)
+def get_observations(**params) -> JsonResponse:
+    """Search observations
 
     .. rubric:: Notes
 
-    * API reference: :v1:`GET /observations/{id} <Observations/get_observations_id>`
+    * :fas:`lock-open` :ref:`Optional authentication <auth>` (For private/obscured coordinates)
+    * API reference: :v1:`GET /observations <Observations/get_observations>`
+
+    Examples:
+
+        Get observations of Monarch butterflies with photos + public location info,
+        on a specific date in the provice of Saskatchewan, CA (place ID 7953):
+
+        >>> response = get_observations(
+        >>>     taxon_name='Danaus plexippus',
+        >>>     created_on='2020-08-27',
+        >>>     photos=True,
+        >>>     geo=True,
+        >>>     geoprivacy='open',
+        >>>     place_id=7953,
+        >>> )
+
+        Get basic info for observations in response:
 
-    Example:
-        >>> response = get_observation(16227955)
         >>> pprint(response)
-        [16227955] [493595] Species: Lixus bardanae observed on 2018-09-05 14:06:00+01:00 by niconoe at 54 rue des Badauds
+        '[57754375] Species: Danaus plexippus (Monarch) observed by samroom on 2020-08-27 at Railway Ave, Wilcox, SK'
+        '[57707611] Species: Danaus plexippus (Monarch) observed by ingridt3 on 2020-08-26 at Michener Dr, Regina, SK'
 
         .. admonition:: Example Response
             :class: toggle
 
-            .. literalinclude:: ../sample_data/get_observation.py
-
-    Args:
-        observation_id: Get the observation with this ID. Only a single value is allowed.
+            .. literalinclude:: ../sample_data/get_observations_node.py
 
     Returns:
-        A dict with details on the observation
-
-    Raises:
-        :py:exc:`.ObservationNotFound` If an invalid observation is specified
+        Response dict containing observation records
     """
+    params = validate_multiple_choice_param(params, 'order_by', V1_OBS_ORDER_BY_PROPERTIES)
 
-    response = get_observations(id=observation_id, **params)
-    if response['results']:
-        return convert_observation_timestamps(response['results'][0])
-    raise ObservationNotFound()
+    if params.get('page') == 'all':
+        observations = paginate_all(get, f'{API_V1}/observations', method='id', **params)
+    else:
+        observations = get(f'{API_V1}/observations', **params).json()
+
+    observations['results'] = convert_all_coordinates(observations['results'])
+    observations['results'] = convert_all_timestamps(observations['results'])
+    return observations
+
+
+@document_common_args
+def get_observations_by_id(
+    observation_id: MultiInt, access_token: Optional[str] = None, **params
+) -> JsonResponse:
+    """Get one or more observations by ID
+
+    .. rubric:: Notes
+
+    * :fas:`lock-open` :ref:`Optional authentication <auth>` (For private/obscured coordinates)
+    * API reference: :v1:`GET /observations/{id} <Observations/get_observations_id>`
+    * This endpoint returns more complete annotation details compared to
+      :py:func:`~pyinaturalist.v1.observations.get_observations`.
+      See :py:class:`.Annotation` for details.
+
+    Example:
+        >>> response = get_observations_by_id(16227955)
+        >>> response = get_observations_by_id([16227955, 16227956])
+
+        .. admonition:: Example Response
+            :class: toggle
+
+            .. literalinclude:: ../sample_data/get_observations_by_id.py
+
+    Args:
+        observation_id: Get an observation with this ID. Multiple IDs are allowed.
+        access_token: An access token, as returned by :py:func:`.get_access_token()`
+
+    Returns:
+        Response dict containing observation records
+    """
+    observations = get(
+        f'{API_V1}/observations', ids=observation_id, access_token=access_token, **params
+    ).json()
+    observations['results'] = convert_all_coordinates(observations['results'])
+    observations['results'] = convert_all_timestamps(observations['results'])
+    return observations
 
 
 @document_request_params(*docs._get_observations, docs._observation_histogram)
@@ -116,54 +175,6 @@ def get_observation_histogram(**params) -> HistogramResponse:
     return convert_observation_histogram(response.json())
 
 
-@document_request_params(*docs._get_observations, docs._pagination, docs._only_id)
-def get_observations(**params) -> JsonResponse:
-    """Search observations
-
-    .. rubric:: Notes
-
-    * API reference: :v1:`GET /observations <Observations/get_observations>`
-
-    Examples:
-
-        Get observations of Monarch butterflies with photos + public location info,
-        on a specific date in the provice of Saskatchewan, CA (place ID 7953):
-
-        >>> response = get_observations(
-        >>>     taxon_name='Danaus plexippus',
-        >>>     created_on='2020-08-27',
-        >>>     photos=True,
-        >>>     geo=True,
-        >>>     geoprivacy='open',
-        >>>     place_id=7953,
-        >>> )
-
-        Get basic info for observations in response:
-
-        >>> pprint(response)
-        '[57754375] Species: Danaus plexippus (Monarch) observed by samroom on 2020-08-27 at Railway Ave, Wilcox, SK'
-        '[57707611] Species: Danaus plexippus (Monarch) observed by ingridt3 on 2020-08-26 at Michener Dr, Regina, SK'
-
-        .. admonition:: Example Response
-            :class: toggle
-
-            .. literalinclude:: ../sample_data/get_observations_node.py
-
-    Returns:
-        Response dict containing observation records
-    """
-    params = validate_multiple_choice_param(params, 'order_by', V1_OBS_ORDER_BY_PROPERTIES)
-
-    if params.get('page') == 'all':
-        observations = paginate_all(get, f'{API_V1}/observations', method='id', **params)
-    else:
-        observations = get(f'{API_V1}/observations', **params).json()
-
-    observations['results'] = convert_all_coordinates(observations['results'])
-    observations['results'] = convert_all_timestamps(observations['results'])
-    return observations
-
-
 @document_request_params(*docs._get_observations, docs._pagination)
 def get_observation_identifiers(**params) -> JsonResponse:
     """Get identifiers of observations matching the search criteria and the count of
@@ -289,7 +300,7 @@ def get_observation_popular_field_values(**params) -> JsonResponse:
     return response_json
 
 
-def get_observation_taxonomy(user_id: IntOrStr = None, **params) -> JsonResponse:
+def get_observation_taxonomy(user_id: Optional[IntOrStr] = None, **params) -> JsonResponse:
     """Get observation counts for all taxa in a full taxonomic tree. In the web UI, these are used
     for life lists.
 
@@ -437,9 +448,9 @@ def update_observation(observation_id: int, **params) -> ListResponse:
 @document_common_args
 def upload(
     observation_id: int,
-    photos: MultiFile = None,
-    sounds: MultiFile = None,
-    photo_ids: MultiIntOrStr = None,
+    photos: Optional[MultiFile] = None,
+    sounds: Optional[MultiFile] = None,
+    photo_ids: Optional[MultiIntOrStr] = None,
     **params,
 ) -> ListResponse:
     """Upload one or more local photo and/or sound files, and add them to an existing observation.
@@ -512,7 +523,7 @@ def upload(
 
 
 @document_request_params(docs._observation_id, docs._access_token)
-def delete_observation(observation_id: int, access_token: str = None, **params):
+def delete_observation(observation_id: int, access_token: Optional[str] = None, **params):
     """Delete an observation
 
     .. rubric:: Notes
@@ -540,3 +551,36 @@ def delete_observation(observation_id: int, access_token: str = None, **params):
     if response.status_code == 404:
         raise ObservationNotFound
     response.raise_for_status()
+
+
+@document_common_args
+def get_observation(
+    observation_id: int, access_token: Optional[str] = None, **params
+) -> ResponseResult:
+    """Get details about a single observation by ID
+
+    .. rubric:: Notes
+
+    * :fas:`triangle-exclamation` Deprecated; use :func:`get_observations`
+      or :func:`get_observations_by_id` instead
+    * :fas:`lock-opens` :ref:`Optional authentication <auth>` (For private/obscured coordinates)
+    * API reference: :v1:`GET /observations/{id} <Observations/get_observations_id>`
+
+    Example:
+        >>> response = get_observation(16227955)
+
+    Args:
+        observation_id: Get the observation with this ID. Only a single value is allowed.
+        access_token: An access token, as returned by :py:func:`.get_access_token()`
+
+    Returns:
+        A dict with details on the observation
+
+    Raises:
+        :py:exc:`.ObservationNotFound` If an invalid observation is specified
+    """
+
+    response = get_observations(id=observation_id, access_token=access_token, **params)
+    if response['results']:
+        return convert_observation_timestamps(response['results'][0])
+    raise ObservationNotFound()
