@@ -1,4 +1,5 @@
 from logging import getLogger
+from typing import Optional
 
 from pyinaturalist.constants import (
     API_V1,
@@ -66,7 +67,7 @@ def get_projects(**params) -> JsonResponse:
 
 def get_projects_by_id(
     project_id: MultiIntOrStr,
-    rule_details: bool = None,
+    rule_details: Optional[bool] = None,
     force_refresh: bool = False,
     **params,
 ) -> JsonResponse:
@@ -115,7 +116,7 @@ def get_projects_by_id(
 
 @document_request_params(docs._project_observation_params)
 def add_project_observation(
-    project_id: int, observation_id: int, access_token: str = None, **params
+    project_id: int, observation_id: int, access_token: Optional[str] = None, **params
 ) -> JsonResponse:
     """Add an observation to a project
 
@@ -161,22 +162,33 @@ def add_project_users(project_id: IntOrStr, user_ids: MultiInt, **params) -> Jso
     Returns:
         The updated project record
     """
-    rules = _get_project_rules(project_id)
-    existing_user_ids = [rule['operand_id'] for rule in rules if rule['operand_type'] == 'User']
+    project = get_projects_by_id(project_id, force_refresh=True)['results'][0]
+    existing_rules = project.get('project_observation_rules', [])
+    existing_user_ids = [
+        rule['operand_id'] for rule in existing_rules if rule['operand_type'] == 'User'
+    ]
+    new_rules = []
+
+    # Minimize payload by sending only new rules
     for user_id in ensure_list(user_ids):
         if user_id not in existing_user_ids:
-            rules.append(
+            new_rules.append(
                 {'operand_id': user_id, 'operand_type': 'User', 'operator': 'observed_by_user?'}
             )
         else:
             logger.warning(f'User {user_id} is already in project rules for {project_id}')
-    return update_project(project_id, project_observation_rules_attributes=rules, **params)
+
+    if not new_rules:
+        logger.info('No project rules to update')
+        return project
+
+    return update_project(project_id, project_observation_rules_attributes=new_rules, **params)
 
 
 # TODO: This may not yet be working as intended
 @document_request_params(docs._project_observation_params)
 def delete_project_observation(
-    project_id: int, observation_id: int, access_token: str = None, **params
+    project_id: int, observation_id: int, access_token: Optional[str] = None, **params
 ):
     """Remove an observation from a project
 
@@ -222,14 +234,25 @@ def delete_project_users(project_id: IntOrStr, user_ids: MultiInt, **params) ->
         The updated project record
     """
     # Get and modify existing rules
-    rules = _get_project_rules(project_id)
+
+    project = get_projects_by_id(project_id, force_refresh=True)['results'][0]
+    existing_rules = project.get('project_observation_rules', [])
+    delete_rules = []
     str_user_ids = [str(user_id) for user_id in ensure_list(user_ids)]
-    for rule in rules:
+
+    for rule in existing_rules:
         if rule['operand_type'] == 'User' and str(rule['operand_id']) in str_user_ids:
             rule['_destroy'] = True
+            delete_rules.append(rule)
+
+    if not delete_rules:
+        logger.info('No project rules to update')
+        return project
 
     # Update project and validate results
-    project = update_project(project_id, project_observation_rules_attributes=rules, **params)
+    project = update_project(
+        project_id, project_observation_rules_attributes=delete_rules, **params
+    )
     _validate_removed_users(project, user_ids)
     return project
 
@@ -280,13 +303,6 @@ def update_project(project_id: IntOrStr, **params) -> JsonResponse:
     return response.json()
 
 
-def _get_project_rules(project_id):
-    """Get the current rules for a project"""
-    response = get_projects_by_id(project_id, force_refresh=True)
-    project = response['results'][0]
-    return project.get('project_observation_rules', [])
-
-
 def _validate_removed_users(project: JsonResponse, user_ids: MultiInt):
     """Validate that users have been removed from project observation rules"""
     updated_user_ids = [
