@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pyinaturalist.constants import API_V1, JsonResponse, MultiInt
 from pyinaturalist.converters import convert_all_timestamps
 from pyinaturalist.docs import document_request_params
@@ -42,7 +44,13 @@ def get_taxa(**params) -> JsonResponse:
     return taxa
 
 
-def get_taxa_by_id(taxon_id: MultiInt, **params) -> JsonResponse:
+def get_taxa_by_id(
+    taxon_id: MultiInt,
+    locale: Optional[str] = None,
+    preferred_place_id: Optional[int] = None,
+    all_names: Optional[bool] = None,
+    **params,
+) -> JsonResponse:
     """Get one or more taxa by ID
 
     .. rubric:: Notes
@@ -66,12 +74,22 @@ def get_taxa_by_id(taxon_id: MultiInt, **params) -> JsonResponse:
             .. literalinclude:: ../sample_data/get_taxa_by_id.py
 
     Args:
-        taxon_id: Get taxa with this ID. Multiple values are allowed.
+        taxon_id: Get taxon with this ID. Multiple values are allowed.
+        locale: Locale preference for taxon common names
+        preferred_place_id: Place preference for regional taxon common names
+        all_names: Include all taxon names in the response
 
     Returns:
         Response dict containing taxon records
     """
-    response = get(f'{API_V1}/taxa', ids=taxon_id, **params)
+    response = get(
+        f'{API_V1}/taxa',
+        ids=taxon_id,
+        locale=locale,
+        preferred_place_id=preferred_place_id,
+        all_names=all_names,
+        **params,
+    )
     taxa = response.json()
     taxa['results'] = convert_all_timestamps(taxa['results'])
     return taxa
