@@ -1,12 +1,12 @@
 from pyinaturalist.client import iNatClient
-from pyinaturalist.constants import API_V1_BASE_URL
+from pyinaturalist.constants import API_V1
 from pyinaturalist.models import User
 from test.sample_data import SAMPLE_DATA
 
 
 def test_from_id(requests_mock):
     requests_mock.get(
-        f'{API_V1_BASE_URL}/users/1',
+        f'{API_V1}/users/1',
         json=SAMPLE_DATA['get_user_by_id'],
         status_code=200,
     )
@@ -18,12 +18,12 @@ def test_from_id(requests_mock):
 
 def test_from_ids(requests_mock):
     requests_mock.get(
-        f'{API_V1_BASE_URL}/users/1',
+        f'{API_V1}/users/1',
         json=SAMPLE_DATA['get_user_by_id'],
         status_code=200,
     )
     requests_mock.get(
-        f'{API_V1_BASE_URL}/users/2',
+        f'{API_V1}/users/2',
         json=SAMPLE_DATA['get_user_by_id'],
         status_code=200,
     )
@@ -35,7 +35,7 @@ def test_from_ids(requests_mock):
 
 def test_autocomplete(requests_mock):
     requests_mock.get(
-        f'{API_V1_BASE_URL}/users/autocomplete',
+        f'{API_V1}/users/autocomplete',
         json=SAMPLE_DATA['get_users_autocomplete'],
         status_code=200,
     )
