@@ -9,13 +9,14 @@
 * Formatting in the model's __str__ method
 """
 from copy import deepcopy
-from datetime import datetime
+from datetime import date, datetime
 
 # flake8: noqa: F405
 import pytest
 from dateutil.tz import tzoffset, tzutc
 
 from pyinaturalist.constants import (
+    API_V1,
     ICONIC_TAXA,
     INAT_BASE_URL,
     PHOTO_BASE_URL,
@@ -85,13 +86,135 @@ def test_deduplicate():
     assert len(obs_list) == 2
 
 
+def test_to_dict():
+    obs_dict = Observation.from_json(j_observation_1).to_dict()
+    assert obs_dict['id'] == j_observation_1['id']
+    assert obs_dict['user']['login'] == j_observation_1['user']['login']
+
+
+def test_to_dict__specific_keys():
+    keys = ['id', 'created_at', 'taxon']
+    obs_dict = Observation.from_json(j_observation_1).to_dict(keys=['id', 'created_at', 'taxon'])
+    assert list(obs_dict.keys()) == keys
+    assert obs_dict['id'] == j_observation_1['id']
+    assert isinstance(obs_dict['created_at'], datetime)
+    assert obs_dict['taxon']['id'] == j_observation_1['taxon']['id']
+
+
+@define
+class ExampleModel(BaseModel):
+    key: str = field(default=None)
+
+
+def test_default_rich_repr():
+    """If no __rich_repr__ or _str_attrs is defined, fall back to printing all attrs fields"""
+    obj = ExampleModel(key='value')
+    print_attrs = [a[0] for a in obj.__rich_repr__()]
+    assert print_attrs == ['id', 'key']
+
+
+# Conservation Statuses
+# --------------------
+
+
+@pytest.mark.parametrize(
+    'status, iucn_id, authority, expected_name',
+    [
+        # IUCN Red List
+        ('LC', None, 'IUCN', 'least concern'),
+        ('vu', None, 'iucn', 'vulnerable'),
+        # IUCN ID only
+        (None, 0, None, 'not evaluated'),
+        # NatureServe
+        ('X', None, 'NatureServe', 'extinct'),
+        ('2', None, 'NatureServe', 'imperiled'),
+        ('G2', None, 'NatureServe', 'imperiled'),
+        ('S2', None, 'NatureServe', 'imperiled'),
+        ('S2S3', None, 'NatureServe', 'imperiled'),
+        ('N2N4', None, 'NatureServe', 'vulnerable'),
+        # Other authority using NatureServe format
+        ('S3S4B', None, 'Vermont Fish & Wildlife', 'vulnerable'),
+        # Norma Oficial
+        ('A', None, 'norma_oficial_059', 'amenazada'),
+        ('PR', None, 'Norma', 'sujeta a protección especial'),
+        # Generic
+        ('E', None, None, 'endangered'),
+        ('LC', None, None, 'least concern'),
+        ('sc', None, None, 'special concern'),
+        # Unknown
+        ('ASDF', None, None, 'placeholder status'),
+        ('ASDF', None, 'NatureServe', 'placeholder status'),
+        ('S2S9', None, 'NatureServe', 'placeholder status'),
+    ],
+)
+def test_conservation_status__derived_status_name(status, iucn_id, authority, expected_name):
+    cs = ConservationStatus(
+        status=status,
+        status_name='placeholder status',
+        iucn=iucn_id,
+        authority=authority,
+    )
+    assert cs.status_name == expected_name
+
+
+def test_conservation_status__display_name():
+    cs = ConservationStatus(
+        status='S2S3B',
+        iucn=2,
+        authority='NatureServe',
+        place=Place(name='Nova Scotia', display_name='Nova Scotia, CA'),
+    )
+    assert cs.display_name == 'imperiled (S2S3B) in Nova Scotia, CA'
+
+    cs.place.display_name = None
+    assert cs.display_name == 'imperiled (S2S3B) in Nova Scotia'
+
+    cs.place = None
+    assert cs.display_name == 'imperiled (S2S3B)'
+
+
+def test_conservation_status__display_name_duplication():
+    """Simplify a redundant display name like "extinct (EXTINCT)" """
+    cs = ConservationStatus(
+        status='extinct',
+        status_name='extinct',
+        iucn=70,
+    )
+    assert cs.display_name == 'extinct'
+
+
+def test_conservation_status__original_status_name():
+    cs_json = deepcopy(j_conservation_status)
+    cs_json['status_name'] = 'replace_me'
+    cs = ConservationStatus.from_json(cs_json)
+    assert cs.status_name == 'imperiled'
+    assert cs._original_status_name == 'replace_me'
+
+
+def test_conservation_status__id_wrapper_properties():
+    cs = ConservationStatus(place_id=1, user_id=2, updater_id=3)
+    assert cs.place.id == cs.place_id == 1
+    assert cs.user.id == cs.user_id == 2
+    assert cs.updater.id == cs.updater_id == 3
+
+
+def test_conservation_status__str():
+    cs_json = deepcopy(j_conservation_status)
+    cs_json['place'] = {'name': 'Test Location'}
+    cs = ConservationStatus.from_json(cs_json)
+    assert str(cs) == (
+        'ConservationStatus(status_name=imperiled, status=S2B, authority=NatureServe, '
+        'place_name=Test Location)'
+    )
+
+
 # Controlled Terms
 # --------------------
 
 
 def test_annotation__converters():
     annotation = Annotation.from_json(j_annotation_1)
-    assert isinstance(annotation.user, User) and annotation.user.id == 2115051
+    assert isinstance(annotation.user, User) and annotation.user.id == 886482
 
 
 def test_annotation__empty():
@@ -100,14 +223,34 @@ def test_annotation__empty():
     assert annotation.user is None
 
 
-def test_annotation__values():
-    annotation = Annotation.from_json(j_annotation_1)
-    assert annotation.values == ['1', '2']
+def test_annotation__init_from_ids():
+    annotation = Annotation(controlled_attribute_id=1, controlled_value_id=2)
+    assert annotation.controlled_attribute.id == 1
+    assert annotation.controlled_value.id == 2
 
 
-def test_annotation__str():
+def test_annotation__init_from_labels():
+    annotation = Annotation(term='Life Stage', value='Adult')
+    assert annotation.controlled_attribute.label == 'Life Stage'
+    assert annotation.controlled_value.label == 'Adult'
+
+
+def test_annotation__label_setters():
+    annotation = Annotation(controlled_attribute={'id': 1}, controlled_value={'id': 2})
+    annotation.term = 'Life Stage'
+    annotation.value = 'Adult'
+    assert annotation.controlled_attribute.label == 'Life Stage'
+    assert annotation.controlled_value.label == 'Adult'
+
+
+def test_annotation__str_with_labels():
     annotation = Annotation.from_json(j_annotation_1)
-    assert str(annotation) == 'Annotation(controlled_attribute_id=1, concatenated_attr_val=1|2)'
+    assert str(annotation) == 'Annotation(term=Life Stage, value=Adult)'
+
+
+def test_annotation__str_without_labels():
+    annotation = Annotation(controlled_attribute_id=1, controlled_value_id=2)
+    assert str(annotation) == 'Annotation(term=1, value=2)'
 
 
 def test_controlled_term__converters():
@@ -130,6 +273,13 @@ def test_controlled_term__properties():
     )
 
 
+def test_controlled_term__get_value_by_id():
+    controlled_term = ControlledTerm.from_json(j_controlled_term_1)
+    value = controlled_term.get_value_by_id(13)
+    assert value.label == 'Flowering'
+    assert controlled_term.get_value_by_id(999) is None
+
+
 def test_controlled_term__str():
     controlled_term = ControlledTerm.from_json(j_controlled_term_1)
     assert str(controlled_term) == (
@@ -146,6 +296,18 @@ def test_controlled_term__value():
     )
 
 
+def test_controlled_term_counts():
+    controlled_term_counts = ControlledTermCounts.from_json(
+        SAMPLE_DATA['get_observation_popular_field_values']
+    )
+    count_1 = controlled_term_counts[0]
+    assert isinstance(count_1, ControlledTermCount)
+    assert isinstance(count_1.controlled_attribute, ControlledTerm)
+    assert isinstance(count_1.controlled_value, ControlledTermValue)
+    assert count_1.term == 'Life Stage'
+    assert count_1.value == 'Adult'
+
+
 # Comments
 # --------------------
 
@@ -187,10 +349,9 @@ def test_identification__empty():
 
 def test_identification__str():
     identification = ID.from_json(j_identification_3)
-    print(identification._nested)
     assert str(identification) == (
-        'Identification(id=126501311, taxon_name=Species: Danaus plexippus (Monarch), '
-        'created_at=Aug 27, 2020)'
+        'Identification(id=126501311, username=samroom, taxon_name=Species: '
+        'Danaus plexippus (Monarch), created_at=Aug 27, 2020, truncated_body=)'
     )
 
 
@@ -286,23 +447,37 @@ def test_observation__project_observations():
     assert isinstance(proj_obs, ProjectObservation) and proj_obs.id == 48899479
 
 
-def test_observation__thumbnail_url():
+def test_observation__default_photo():
     obs = Observation.from_json(j_observation_2)
     assert (
-        obs.thumbnail_url == 'https://static.inaturalist.org/photos/92152429/square.jpg?1598551272'
+        obs.default_photo.original_url
+        == 'https://static.inaturalist.org/photos/92152429/original.jpg?1598551272'
     )
 
 
+def test_observation__missing_default_photo():
+    obs = Observation.from_json(j_observation_2)
+    obs.photos = []
+    assert obs.default_photo.original_url.endswith('insecta-200px.png')
+
+
+def test_observation__missing_default_photo_and_taxon():
+    obs = Observation.from_json(j_observation_2)
+    obs.photos = []
+    obs.taxon = None
+    assert obs.default_photo.original_url.endswith('unknown-200px.png')
+
+
 def test_observations():
     obs_list = Observations.from_json_list(
         [j_observation_1, j_observation_1, j_observation_2, j_observation_3_ofvs]
     )
     assert isinstance(obs_list.identifiers[0], User) and len(obs_list.identifiers) == 6
     assert isinstance(obs_list.observers[0], User) and len(obs_list.observers) == 3
+    assert isinstance(obs_list.photos[0], Photo) and len(obs_list.photos) == 4
     assert isinstance(obs_list.taxa[0], Taxon) and len(obs_list.taxa) == 3
-    assert len(obs_list.thumbnail_urls) == 4
     assert (
-        obs_list.thumbnail_urls[0]
+        obs_list.photos[0].thumbnail_url
         == 'https://static.inaturalist.org/photos/24355315/square.jpeg?1536150664'
     )
 
@@ -331,7 +506,7 @@ def test_observation_field__str():
     )
 
 
-def test_observation_field_value__converters():
+def test_observation_field_value__numeric():
     ofv = OFV.from_json(j_ofv_1_numeric)
     assert ofv.datatype == 'numeric'
     assert ofv.value == 100
@@ -339,11 +514,6 @@ def test_observation_field_value__converters():
     assert isinstance(ofv.user, User) and ofv.user.id == 2115051
 
 
-def test_observation_field_value__converter_error():
-    ofv = OFV(datatype='numeric', value='one')
-    assert ofv.value is None
-
-
 def test_observation_field_value__taxon():
     ofv = OFV.from_json(j_ofv_2_taxon)
     assert ofv.datatype == 'taxon'
@@ -351,6 +521,25 @@ def test_observation_field_value__taxon():
     assert isinstance(ofv.taxon, Taxon) and ofv.taxon.id == 119900
 
 
+def test_observation_field_value__date():
+    ofv = OFV.from_json(j_ofv_3_date)
+    assert ofv.datatype == 'date'
+    assert ofv.value == date(2022, 11, 9)
+    assert ofv.taxon is None
+
+
+def test_observation_field_value__datetime():
+    ofv = OFV.from_json(j_ofv_4_datetime)
+    assert ofv.datatype == 'datetime'
+    assert ofv.value == datetime(2022, 11, 9, 11, 20, 42)
+    assert ofv.taxon is None
+
+
+def test_observation_field_value__converter_error():
+    ofv = OFV(datatype='taxon', value='birb')
+    assert ofv.value is None
+
+
 def test_observation_field_value__empty():
     ofv = OFV()
     assert ofv.value is None
@@ -519,8 +708,19 @@ def test_taxon__empty():
 
 
 def test_taxon__str():
+    taxon_0 = Taxon(
+        id=137338523,
+        name='Trachelipus rathkii',
+        preferred_common_name='rathke’s woodlouse',
+        rank='species',
+    )
+    assert (
+        str(taxon_0)
+        == 'Taxon(id=137338523, full_name=Species: Trachelipus rathkii (Rathke’s Woodlouse))'
+    )
+
     taxon_1 = Taxon(id=3, name='Aves', preferred_common_name='birb', rank='class')
-    assert str(taxon_1) == 'Taxon(id=3, full_name=Class: Aves (birb))'
+    assert str(taxon_1) == 'Taxon(id=3, full_name=Class: Aves (Birb))'
 
     taxon_2 = Taxon(id=3, name='Aves', rank='class')
     assert str(taxon_2) == 'Taxon(id=3, full_name=Class: Aves)'
@@ -563,9 +763,7 @@ def test_taxon__autocomplete():
 def test_taxon__conservation_status():
     cs = Taxon.from_json(j_taxon_5_cs_status).conservation_status
     assert isinstance(cs, ConservationStatus)
-    assert cs.authority == 'NatureServe'
     assert cs.status_name == 'imperiled'
-    assert str(cs) == 'ConservationStatus(status_name=imperiled, status=S2B, authority=NatureServe)'
 
 
 def test_taxon__conservation_status_aliases():
@@ -581,7 +779,7 @@ def test_taxon__conservation_status_aliases():
 def test_taxon__conservation_statuses():
     css = Taxon.from_json(j_taxon_6_cs_statuses).conservation_statuses[0]
     assert isinstance(css, ConservationStatus)
-    assert css.status == "EN"
+    assert css.status == 'EN'
     assert isinstance(css.updater, User) and css.user.id == 383144
     assert isinstance(css.user, User) and css.user.id == 383144
 
@@ -607,6 +805,19 @@ def test_taxon__listed_taxa():
     )
 
 
+def test_listed_taxon__id_wrapper_properties():
+    lt = ListedTaxon(list_id=299, place_id=1, user_id=2, updater_id=3)
+    assert lt.list.id == lt.list_id == 299
+    assert lt.place.id == lt.place_id == 1
+    assert lt.user.id == lt.user_id == 2
+    assert lt.updater.id == lt.updater_id == 3
+
+    # Init with both list ID and object
+    lt = ListedTaxon(list_id=299, list=Checklist(title='test checklist'))
+    assert lt.list.id == 299
+    assert lt.list.title == 'test checklist'
+
+
 def test_taxon__properties():
     taxon = Taxon.from_json(j_taxon_1)
     assert taxon.url == f'{INAT_BASE_URL}/taxa/70118'
@@ -660,9 +871,17 @@ def test_taxon__taxonomy():
     }
 
 
-# TODO
-def test_taxon__update_from_full_record():
-    pass
+def test_taxon__load_full_record(requests_mock):
+    requests_mock.get(
+        f'{API_V1}/taxa/343248',
+        json=load_sample_data('get_taxa_by_id.json'),
+        status_code=200,
+    )
+    taxon = Taxon(id=343248, matched_term='nicroph')
+    taxon.load_full_record()
+    assert taxon.name == 'Nicrophorus vespilloides'
+    assert taxon.matched_term == 'nicroph'  # matched_term should not be overwritten if present
+    assert len(taxon.ancestors) == 12
 
 
 def test_taxon_count__copy():
